cookies_utilities — cookies_utilities 0.0.1 documentation

# cookies_utilities

- Documentation
  - Functions
    - cookies_utilities.copy_datetime
      - `copy_datetime()`
    - cookies_utilities.get_dates
      - `get_dates()`
    - cookies_utilities.convert_time_to_feature
      - `convert_time_to_feature()`
    - cookies_utilities.has_diff_local_and_remote
      - `has_diff_local_and_remote()`
  - Classes
    - cookies_utilities.Stopwatch
      - `Stopwatch`
    - cookies_utilities.HtmlHelper
      - `HtmlHelper`